package App::efm_perl;
use 5.008001;
use strict;
use warnings;

our $VERSION = "0.04";



1;
__END__

=for stopwords efm-perl errorformat

=encoding utf-8

=head1 NAME

App::efm_perl - It's new $module

=head1 DESCRIPTION

This is a stub module containing the binary below.

F<efm-perl> - perl -c executable with errorformat friendly outputs

=head1 LICENSE

Copyright (C) delphinus.

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

=head1 AUTHOR

delphinus E<lt>me@delphinus.devE<gt>

=cut

